YA_STRING: str = "YANDEX.STRING"
"""Тип строка"""

YA_NUMBER: str = "YANDEX.NUMBER"
"""Тип число"""

YA_DATETIME: str = "YANDEX.DATETIME"
"""Тип дата, может быть относительной"""

YA_FIO: str = "YANDEX.FIO"
"""Тип ФИО"""

YA_GEO: str = "YANDEX.GEO"
"""Тип географические данные"""

# Специфичные типы

YA_CONFIRM: str = "YANDEX.CONFIRM"
"""Тип согласие пользователя"""

YA_REJECT: str = "YANDEX.REJECT"
"""Тип отказ пользователя"""

YA_HELP: str = "YANDEX.HELP"
"""Тип пользователь запросил помощь"""

YA_REPEAT: str = "YANDEX.REPEAT"
"""Тип пользователь попросил повторить"""

YA_WHAT_CAN_YOU_DO: str = "YANDEX.WHAT_CAN_YOU_DO"
"""Тип пользователь спросил что может навык
    
    Документация: https://yandex.ru/dev/dialogs/alice/doc/requirements.html#specific__content"""
